@@ -9,16 +9,16 @@ __banner__ = r"""
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 """
 
-__version__ = '1.3.2'
+__version__ = '1.6.1'
 __title__ = 'instamatic'
 __long_title__ = f'{__title__} v{__version__}'
 __author__ = 'Stef Smeets'
 __author_email__ = 's.smeets@tudelft.nl'
 __description__ = 'Python program for automated serial electron diffraction data collection'
 __license__ = 'GPLv3'
-__url__ = 'http://github.com/stefsmeets/instamatic'
+__url__ = 'http://github.com/instamatic-dev/instamatic'
 __doi__ = 'https://doi.org/10.5281/zenodo.1090388'
-__citation__ = f'Instamatic (Version 1.1), Zenodo (2019), {__doi__}'
+__citation__ = f'Instamatic (v.{__version__}), Zenodo, {__doi__}'
 __citation_cred__ = 'J. Appl. Cryst. (2018). 51, 1652–1661, https://doi.org/10.1107/S1600576718015145'
 __citation_serialed__ = 'J. Appl. Cryst. (2018). 51, 1262–1273, https://doi.org/10.1107/S1600576718009500'
 __citation_serialred__ = 'IUCrJ. (2019). 6(5), 854-867, https://doi.org/10.1107/S2052252519007681'
