@@ -10,7 +10,7 @@ from pathlib import Path
 
 import numpy as np
 from scipy import ndimage
-from skimage.feature import register_translation
+from skimage.registration import phase_cross_correlation
 from tqdm.auto import tqdm
 
 from instamatic import config
@@ -44,8 +44,8 @@ from instamatic.tools import find_defocused_image_center
 # imgvar_threshold = 600
 
 date = datetime.datetime.now().strftime('%Y-%m-%d')
-log_rotaterange = config.logs_drc / f'Rotrange_stagepos_{date}.log'
-log_iscalibs = config.logs_drc / f'ImageShift_LOGS_{date}'
+log_rotaterange = config.locations['logs'] / f'Rotrange_stagepos_{date}.log'
+log_iscalibs = config.locations['logs'] / f'ImageShift_LOGS_{date}'
 log_iscalibs.mkdir(exist_ok=True)
 
 if not os.path.isfile(log_rotaterange):
@@ -78,7 +78,7 @@ def load_IS_Calibrations(imageshift, ctrl, diff_defocus, logger, mode):
 
     try:
         if imageshift == 'S':
-            with open(config.logs_drc / file, 'rb') as f:
+            with open(config.locations['logs'] / file, 'rb') as f:
                 transform_imgshift, c = pickle.load(f)
         else:
             with open(log_iscalibs / file, 'rb') as f:
@@ -355,7 +355,7 @@ class Experiment:
             displacement = np.subtract((258, 258), pos_arr)
             mag = self.ctrl.magnification.value
 
-            s = config.calibration.pixelsize_mag1[mag] / 1000  # nm -> um
+            s = config.calibration['mag1']['pixelsize'][mag] / 1000  # nm -> um
             # print("scaling facor: {} um per px".format(s))
 
             mvmt = s * displacement
@@ -713,7 +713,7 @@ class Experiment:
 
                     if trackmethod == 'c':
 
-                        cc, err, diffphase = register_translation(img0_cropped, img_cropped)
+                        cc, err, diffphase = phase_cross_correlation(img0_cropped, img_cropped)
                         self.logger.debug(f'Cross correlation result: {cc}')
 
                         if self.guess_crystmove and i >= self.nom_ii:
@@ -858,7 +858,7 @@ class Experiment:
 
         rotation_angle = config.camera.camera_rotation_vs_stage_xy
 
-        self.pixelsize = config.calibration.pixelsize_diff[camera_length]  # px / Angstrom
+        self.pixelsize = config.calibration['diff']['pixelsize'][camera_length]  # px / Angstrom
         self.physical_pixelsize = config.camera.physical_pixelsize  # mm
         self.wavelength = config.microscope.wavelength  # angstrom
         self.stretch_azimuth = config.camera.stretch_azimuth
@@ -992,7 +992,7 @@ class Experiment:
 
     def raster_scan(self):
         from instamatic.experiments.serialed.experiment import get_offsets_in_scan_area
-        pixelsize_mag1 = config.calibration.pixelsize_mag1[self.magnification] / 1000  # nm -> um
+        pixelsize_mag1 = config.calibration['mag1']['pixelsize'][self.magnification] / 1000  # nm -> um
         xdim, ydim = self.ctrl.getCameraDimensions()
         box_x, box_y = self.pixelsize_mag1 * xdim, self.pixelsize_mag1 * ydim
 
