@@ -253,8 +253,7 @@ class Experiment:
 
         self.emmenu.set_exposure(self.exposure)
 
-        self.beamblank_is_on = self.ctrl.beamblank
-        if not self.beamblank_is_on:
+        if not self.ctrl.beam.is_blanked:
             self.ctrl.beam.blank()
 
         self.ctrl.screen.up()
@@ -387,7 +386,7 @@ class Experiment:
         t1 = time.perf_counter()
         self.emmenu.stop_liveview()
 
-        if self.beamblank_is_on:
+        if self.ctrl.beam.is_blanked:
             self.ctrl.beam.blank()
 
         self.end_position = self.ctrl.stage.get()
@@ -459,7 +458,7 @@ class Experiment:
         wavelength = config.microscope.wavelength
 
         try:
-            pixelsize = config.calibration.pixelsize_diff[self.camera_length]  # px / Angstrom
+            pixelsize = config.calibration['diff']['pixelsize'][self.camera_length]  # px / Angstrom
         except KeyError:
             print(f'Warning: No such camera length: {self.camera_length} in diff calibration, defaulting to 1.0')
             pixelsize = 1.0
